@@ -9,47 +9,47 @@ from netbox.forms import (
     NetBoxModelForm,
 )
 
-from netbox_storage.models import VolumeGroup
+from netbox_storage.models import Drive, VolumeGroup
 
 
 class VolumeGroupForm(NetBoxModelForm):
-    """Form for creating a new VolumeGroup object."""
-
-    vg_name = CharField(
-        label="VG Name",
-        help_text="Volume Group Name e.g. docker",
+    description = CharField(
+        required=False,
+        label="Description",
+        help_text="Short Description e.g. VolumeGroup 1 on SSD Cluster",
     )
 
     class Meta:
         model = VolumeGroup
 
         fields = (
-            "vg_name",
             "description",
         )
 
 
 class VolumeGroupFilterForm(NetBoxModelFilterSetForm):
-    """Form for filtering VolumeGroup instances."""
 
     model = VolumeGroup
 
-    vg_name = CharField(
+    description = CharField(
         required=False,
-        label="VG Name",
+        label="Description",
+        help_text="Short Description e.g. VolumeGroup 1 on SSD Cluster",
     )
 
 
 class VolumeGroupImportForm(NetBoxModelImportForm):
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    description = CharField(
+        required=False,
+        label="Description",
+        help_text="Short Description e.g. VolumeGroup 1 on SSD Cluster",
+    )
 
     class Meta:
         model = VolumeGroup
 
         fields = (
-            "vg_name",
             "description",
         )
 
@@ -57,16 +57,16 @@ class VolumeGroupImportForm(NetBoxModelImportForm):
 class VolumeGroupBulkEditForm(NetBoxModelBulkEditForm):
     model = VolumeGroup
 
-    vg_name = CharField(
+    description = CharField(
         required=False,
-        label="VG Name",
+        label="Description",
+        help_text="Short Description e.g. VolumeGroup 1 on SSD Cluster",
     )
-    description = CharField(max_length=255, required=False)
 
     fieldsets = (
         (
             None,
-            ("vg_name", "description"),
+            ["description"]
         ),
     )
     nullable_fields = ["description"]
